pub struct Mirror {
pub url: String,
pub protocol: Protocol,
pub completion_pct: f32,
pub delay: Option<i64>,
pub score: Option<f64>,
pub duration_stddev: Option<f64>,
pub last_sync: Option<DateTime<Utc>>,
pub ipv4: bool,
pub ipv6: bool,
pub isos: bool,
}Expand description
An ArchLinux mirror
Fields
url: StringThe mirror’s URL
protocol: ProtocolRepresents a mirror’s protocol
completion_pct: f32The number of mirror checks that have successfully connected and disconnected from the given URL. If it’s less than 100, it may be a sign of an unreliable mirror
delay: Option<i64>The calculated average mirroring delay; e.g. the mean value of last_check − last_sync for each check of this mirror URL. Any value under one hour should be viewed as ideal.
score: Option<f64>A very rough calculation for ranking mirrors. It is currently calculated as (hours delay + average duration + standard deviation) / completion percentage. Lower is better.
duration_stddev: Option<f64>The standard deviation of the connect and retrieval time. A high standard deviation can indicate an unstable or overloaded mirror.
last_sync: Option<DateTime<Utc>>time only.Time when the last successful synchronisation occurred
ipv4: boolipv4 enabled
ipv6: boolipv6 enabled
isos: boolisos enabled